#!/bin/bash
#
#   NOTE:  we build libxslt with the native compiler

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <debug|opt|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing

product_dir=${1}
extraqual=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=libxslt
origpkgver=v1_1_32
pkgver=${origpkgver//-/_}
ssibuildshims_version=v1_04_12
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
pkgtardir=${package}-${pkgdotver%-rc*}

get_this_dir
get_ssibuildshims
source define_basics NO_BASE_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [ "${extraqual}" = "debug" ]
then
    cxxflg="-g -O0"
elif [ "${extraqual}" = "opt" ]
then
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "prof" ]
then
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
  ssi_die "unrecognized build type \"$extraqual\""
fi

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# setup root
setup -B ${package} ${pkgver} -q +${fullqual//:/:+} -z ${fakedb}:${product_dir}:${PRODUCTS} || \
 ssi_die "fake setup failed: unsupported qualifier?"

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

set -x

cd ${sourcedir}
tar xf ${tardir}/${pkgtarname}.tar.gz

export LIBXSLT_SOURCE=${sourcedir}/${pkgtardir}

cd "${LIBXSLT_SOURCE}"

for patch in ${patchdir}/*.patch; do
  if grep -e '^\(---\|+++\) [ab]/' ${patch} >/dev/null 2>&1; then
    pval=1
  else
    pval=0
  fi
  patch ${DEBUG_PATCHES:+--verbose} -p${pval} < "${patch}" || ssi_die "application of patch ${patch} failed."
done

cd ${blddir}
CFLAGS="${cxxflg}" ${LIBXSLT_SOURCE}/configure --prefix=${pkgdir} --without-python || ssi_die "configure failed."
make -j ${ncore} || ssi_die "make failed."
make -j ${ncore} check || ssi_die "make check failed."
make -j ${ncore} install || ssi_die "make install failed."

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS} || ssi_die "unable to set up product."
echo "${package} headers are installed in ${LIBXSLT_INC}"

# fixing embedded path
mv ${LIBXSLT_FQ_DIR}/bin/xslt-config ${LIBXSLT_FQ_DIR}/bin/xslt-config.bak
cat ${LIBXSLT_FQ_DIR}/bin/xslt-config.bak | sed 's%^prefix=.*$%prefix=${LIBXSLT_FQ_DIR}%' > ${LIBXSLT_FQ_DIR}/bin/xslt-config
mv ${LIBXSLT_FQ_DIR}/lib/xsltConf.sh ${LIBXSLT_FQ_DIR}/lib/xsltConf.sh.bak
cat ${LIBXSLT_FQ_DIR}/lib/xsltConf.sh.bak | \
   sed 's%^XSLT_LIBDIR=.*$%XSLT_LIBDIR="-L${LIBXSLT_FQ_DIR}/lib"%' | \
   sed 's%^XSLT_INCLUDEDIR=.*$%XSLT_INCLUDEDIR="-I${LIBXSLT_FQ_DIR}/include/libxslt"%' \
   > ${LIBXSLT_FQ_DIR}/lib/xsltConf.sh
chmod +x ${LIBXSLT_FQ_DIR}/bin/xslt-config

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
